@@ -1,9 +1,7 @@
 #ifndef __Time_Elapsed_h__
 #define __Time_Elapsed_h__
 
-#include <glib/gtypes.h> // for GTimeVal
-#include <glib/gmain.h> // for g_get_current_time
-#include <glib/gtimer.h> // for GUSEC_PER_SEC
+#include <glib.h> // for GTimeVal, g_get_current_time and GUSEC_PER_SEC
 
 namespace pan
 {
@@ -26,6 +24,13 @@ namespace pan
       diff += (finish.tv_usec - start.tv_usec)/(double)G_USEC_PER_SEC;
       return diff;
     }
+
+    double get_usecs_elapsed () const {
+      GTimeVal finish;
+      g_get_current_time (&finish);
+      double diff = finish.tv_usec - start.tv_usec;
+      return diff;
+    }
   };
 }
 
