@@ -13,8 +13,8 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
+ *
  */
 
 #include <pan/general/string-view.h>
@@ -54,6 +54,12 @@ namespace pan
                               const StringView  & key,
                               const StringView  & fallback);
 
+      void set_group_color   (const Quark& group, const GdkColor& color);
+
+      std::string get_group_color_str (const Quark& group) const;
+      static std::string color_to_string (const GdkColor& c);
+      GdkColor get_group_color (const Quark& group, const StringView& fallback_str) const;
+
     protected:
       static void start_element (GMarkupParseContext *context,
                                  const gchar         *element_name,
