@@ -13,14 +13,14 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
+ *
  */
 
 #ifndef __ProfilesDialog_h__
 #define __ProfilesDialog_h__
 
-#include <gtk/gtk.h>
+#include "gtk-compat.h"
 #include <pan/data/data.h>
 
 namespace pan
@@ -43,14 +43,18 @@ namespace pan
       GtkWidget * _username_entry;
       GtkWidget * _address_entry;
       GtkWidget * _msgid_fqdn_entry;
+      GtkWidget * _xface_entry;
       GtkWidget * _attribution_entry;
       GtkWidget * _signature_file_check;
-      GtkWidget * _signature_file;
-      GtkWidget * _signature_file_combo;
       GtkWidget * _server_combo;
       GtkWidget * _extra_headers_tv;
-
+      GtkWidget * _signature_file_combo;
     public:
+
+      GtkWidget * _signature_file_combo_box;
+      GtkWidget * _signature_file;
+      GtkWidget * _gpg_sig_entry;
+
       static bool run_until_valid_or_cancel (ProfileDialog& p);
   };
 
