@@ -13,8 +13,8 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
+ *
  */
 
 #ifndef __TaskPost_h__
@@ -46,7 +46,7 @@ namespace pan
       virtual void use_nntp (NNTP * nntp);
 
     private: // NNTP::Listener's virtual functions
-      virtual void on_nntp_done (NNTP*, Health);
+      virtual void on_nntp_done (NNTP*, Health, const StringView&);
 
     private: // implementation
       Quark _server;
